package session2;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.UniqueConstraint;

/**
 * @author goik
 * 
 *         {@link User} instances with primary key and unique constraint
 * 
 */
@Entity
@Table(uniqueConstraints={@UniqueConstraint(columnNames={"uid"}),
		@UniqueConstraint(columnNames={"uidNumber"})})
public class User {

	@Id
	@GeneratedValue
	private Long id;
	public Long getId() {return id;}
	protected void setId(Long id) {this.id = id;}

	int uidNumber;
	public int getUidNumber() {return uidNumber;}
	public void setUidNumber(int uidNumber) {this.uidNumber = uidNumber;}

	String uid;

	/**
	 * 
	 * @return The user's unique login name e.g. "goik"
	 */
	@Column(nullable=false)
	public String getUid() {return uid;}
	public void setUid(String uid) {this.uid = uid;}

	String cname;
	/**
	 * @return The user's common name e.g. "Martin Goik"
	 */
	@Column(nullable = false)
	public String getCname() {return cname;}
	public void setCname(String cname) {this.cname = cname;}

	/**
	 * Hibernate/JPA require a default constructor
	 */
	public User() {}

	/**
	 * @param uid
	 *          See {@link #getUid()}.
	 * @param cname
	 *          See {@link #getCname()}.
	 */
	public User(int uidNumber, String uid, String cname) {
		setUidNumber(uidNumber);
		setUid(uid);
		setCname(cname);
	}
	@Override
	public boolean equals(Object other) {
		if (this == other) {
			return true;
		} else if (id == null) {
			return false;
		} else if (other instanceof User) {
			final User that = (User) other;
			return this.id.equals( that.getId() );
		} else {
			return false;
		}
	}
	@Override
	public int hashCode() {
		if (null == id) {
			return System.identityHashCode(this);
		} else {
			return id.hashCode();
		}
	}

}